@@ -13,9 +13,7 @@
 #    under the License.
 
 import os
-import subprocess
 import sys
-import warnings
 
 on_rtd = os.environ.get('READTHEDOCS', None) == 'True'
 
@@ -33,9 +31,16 @@ sys.path.insert(0, os.path.abspath('./'))
 
 # Add any Sphinx extension module names here, as strings. They can be extensions
 # coming with Sphinx (named 'sphinx.ext.*') or your custom ones.
-extensions = ['sphinx.ext.autodoc', 'sphinx.ext.doctest', 'sphinx.ext.todo',
+extensions = ['sphinx.ext.autodoc',
+              'sphinx.ext.doctest',
+              'sphinx.ext.todo',
               'sphinx.ext.coverage',
-              'sphinx.ext.viewcode', 'sphinxcontrib.httpdomain',]
+              'oslo_config.sphinxconfiggen',
+              'oslo_config.sphinxext',
+              'oslo_policy.sphinxext',
+              'oslo_policy.sphinxpolicygen',
+              'sphinx.ext.viewcode',
+              'sphinxcontrib.httpdomain',]
 
 if not on_rtd:
     extensions.append('openstackdocstheme')
@@ -49,22 +54,19 @@ source_suffix = '.rst'
 # The master toctree document.
 master_doc = 'index'
 
-# General information about the project.
-project = 'Murano'
-
 # openstackdocstheme options
-repository_name = 'openstack/murano'
-bug_project = 'murano'
-bug_tag = ''
-html_last_updated_fmt = '%Y-%m-%d %H:%M'
+openstackdocs_repo_name = 'openstack/murano'
+openstackdocs_pdf_link = True
+openstackdocs_bug_project = 'murano'
+openstackdocs_bug_tag = ''
 
+config_generator_config_file = '../../etc/oslo-config-generator/murano.conf'
+sample_config_basename = '_static/murano'
 
-# The version info for the project you're documenting, acts as replacement for
-# |version| and |release|, also used in various other places throughout the
-# built documents.
-from murano.version import version_info
-release = version_info.release_string()
-version = version_info.version_string()
+policy_generator_config_file = [
+    ('../../etc/oslo-policy-generator/murano-policy-generator.conf',
+     '_static/murano'),
+]
 
 # Set the default Pygments syntax
 highlight_language = 'python'
@@ -102,3 +104,32 @@ html_sidebars = {
     '**':       ['localtoc.html', 'relations.html',
                  'searchbox.html', 'sourcelink.html']
 }
+
+# Add any paths that contain custom static files (such as style sheets) here,
+# relative to this directory. They are copied after the builtin static files,
+# so a file named "default.css" will overwrite the builtin "default.css".
+# html_static_path = ['_static']
+
+# -- Options for LaTeX output -------------------------------------------------
+
+# Grouping the document tree into LaTeX files. List of tuples
+# (source start file, target name, title, author, documentclass
+# [howto/manual]).
+latex_documents = [
+    ('index', 'doc-murano.tex', u'Murano Documentation',
+     u'OpenStack Foundation', 'manual'),
+]
+latex_domain_indices = False
+
+latex_elements = {
+    'makeindex': '',
+    'printindex': '',
+    'preamble': r'\setcounter{tocdepth}{3}',
+    'maxlistdepth': '10',
+}
+
+# Disable usage of xindy https://bugzilla.redhat.com/show_bug.cgi?id=1643664
+latex_use_xindy = False
+
+# Disable smartquotes, they don't work in latex
+smartquotes_excludes = {'builders': ['latex']}
