@@ -16,12 +16,12 @@ from oslo_db import exception as db_exc
 from oslo_log import log as logging
 from webob import exc
 
-from murano.api.v1 import environments as envs_api
 from murano.api.v1 import request_statistics
-from murano.common.i18n import _, _LE
+from murano.common.i18n import _
 from murano.common import policy
 from murano.common import utils
 from murano.common import wsgi
+from murano.db import models
 from murano.db.services import core_services
 from murano.db.services import environment_templates as env_temps
 from murano.db.services import environments as envs
@@ -35,23 +35,41 @@ API_NAME = 'Templates'
 class Controller(object):
     @request_statistics.stats_count(API_NAME, 'Index')
     def index(self, request):
-        """It lists the env templates associated to an tenant-id.
+        """Lists the env templates associated to an tenant-id
+
+        It lists the env templates associated to an tenant-id.
         :param request: The operation request.
         :return: the env template description list.
         """
         LOG.debug('EnvTemplates:List')
         policy.check('list_env_templates', request.context)
+        tenant_id = request.context.project_id
+        filters = {}
+        if request.GET.get('is_public'):
+            is_public = request.GET.get('is_public', 'false').lower() == 'true'
+            if not is_public:
+
+                filters['is_public'] = False
+                filters['tenant_id'] = tenant_id
+            elif is_public:
+                filters['is_public'] = True
+
+            list_templates = env_temps.EnvTemplateServices.\
+                get_env_templates_by(filters)
+
+        else:
+            filters = (models.EnvironmentTemplate.is_public,
+                       models.EnvironmentTemplate.tenant_id == tenant_id)
+            list_templates = env_temps.EnvTemplateServices.\
+                get_env_templates_or_by(filters)
 
-        filters = {'tenant_id': request.context.tenant}
-        list_templates = env_temps.EnvTemplateServices.\
-            get_env_templates_by(filters)
         list_templates = [temp.to_dict() for temp in list_templates]
-
         return {"templates": list_templates}
 
     @request_statistics.stats_count(API_NAME, 'Create')
     def create(self, request, body):
-        """It creates the env template from the payload obtaining.
+        """Creates the env template from the payload
+
         This payload can contain just the template name, or include
         also service information.
         :param request: the operation request.
@@ -60,26 +78,13 @@ class Controller(object):
         """
         LOG.debug('EnvTemplates:Create <Body {body}>'.format(body=body))
         policy.check('create_env_template', request.context)
+
+        self._validate_body_name(body)
         try:
-            LOG.debug('ENV TEMP NAME: {templ_name}>'.format(
-                templ_name=body['name']))
-            if not envs_api.VALID_NAME_REGEX.match(str(body['name'])):
-                msg = _('Environment Template must contain only alphanumeric '
-                        'or "_-." characters, must start with alpha')
-                LOG.error(msg)
-                raise exc.HTTPBadRequest(msg)
-        except Exception:
-                msg = _('Env template body is incorrect')
-                LOG.exception(msg)
-                raise exc.HTTPClientError(msg)
-        if len(body['name']) > 255:
-            msg = _('Environment Template name should be 255 characters '
-                    'maximum')
-            LOG.exception(msg)
-            raise exc.HTTPBadRequest(explanation=msg)
-        try:
+            LOG.debug('ENV TEMP NAME: {templ_name}>'.
+                      format(templ_name=body['name']))
             template = env_temps.EnvTemplateServices.create(
-                body.copy(), request.context.tenant)
+                body.copy(), request.context.project_id)
             return template.to_dict()
         except db_exc.DBDuplicateEntry:
             msg = _('Env Template with specified name already exists')
@@ -88,7 +93,8 @@ class Controller(object):
 
     @request_statistics.stats_count(API_NAME, 'Show')
     def show(self, request, env_template_id):
-        """It shows the description about a template.
+        """It shows the description of a template
+
         :param request: the operation request.
         :param env_template_id: the env template ID.
         :return: the description of the env template.
@@ -110,7 +116,8 @@ class Controller(object):
 
     @request_statistics.stats_count(API_NAME, 'Update')
     def update(self, request, env_template_id, body):
-        """It updates the description template.
+        """It updates the description template
+
         :param request: the operation request.
         :param env_template_id: the env template ID.
         :param body: the description to be updated
@@ -125,22 +132,23 @@ class Controller(object):
         try:
             LOG.debug('ENV TEMP NAME: {temp_name}>'.format(
                 temp_name=body['name']))
-            if not envs_api.VALID_NAME_REGEX.match(str(body['name'])):
-                msg = _('Env Template must contain only alphanumeric '
-                        'or "_-." characters, must start with alpha')
+            if not str(body['name']).strip():
+                msg = _('Environment Template must contain at least one '
+                        'non-white space symbol')
                 LOG.exception(msg)
                 raise exc.HTTPBadRequest(msg)
         except Exception:
-                msg = _('EnvTemplate body is incorrect')
-                LOG.exception(msg)
-                raise exc.HTTPBadRequest(msg)
+            msg = _('EnvTemplate body is incorrect')
+            LOG.exception(msg)
+            raise exc.HTTPBadRequest(msg)
 
         template = env_temps.EnvTemplateServices.update(env_template_id, body)
         return template.to_dict()
 
     @request_statistics.stats_count(API_NAME, 'Delete')
     def delete(self, request, env_template_id):
-        """It deletes the env template.
+        """It deletes the env template
+
         :param request: the operation request.
         :param env_template_id: the template ID.
         """
@@ -155,6 +163,7 @@ class Controller(object):
 
     def has_services(self, template):
         """"It checks if the template has services
+
         :param template: the template to check.
         :return: True or False
         """
@@ -167,30 +176,22 @@ class Controller(object):
 
     @request_statistics.stats_count(API_NAME, 'Create_environment')
     def create_environment(self, request, env_template_id, body):
-        """Creates environment and session from template.
+        """Creates environment and session from template
+
         :param request: operation request
         :param env_template_id: environment template ID
         :param body: the environment name
         :return: session_id and environment_id
         """
-        LOG.debug('Templates:Create environment <Id: {templ_id}>'.
-                  format(templ_id=env_template_id))
         target = {"env_template_id": env_template_id}
         policy.check('create_environment', request.context, target)
 
         self._validate_request(request, env_template_id)
+        LOG.debug('Templates:Create environment <Id: {templ_id}>'.
+                  format(templ_id=env_template_id))
         template = env_temps.EnvTemplateServices.\
             get_env_template(env_template_id)
-
-        if ('name' not in body or
-                not envs_api.VALID_NAME_REGEX.match(str(body['name']))):
-            msg = _('Environment must contain only alphanumeric '
-                    'or "_-." characters, must start with alpha')
-            LOG.error(msg)
-            raise exc.HTTPBadRequest(explanation=msg)
-        LOG.debug('ENVIRONMENT NAME: {env_name}>'.format(
-            env_name=body['name']))
-
+        self._validate_body_name(body)
         try:
             environment = envs.EnvironmentServices.create(
                 body.copy(), request.context)
@@ -216,19 +217,75 @@ class Controller(object):
         )
         return {"session_id": session.id, "environment_id": environment.id}
 
+    @request_statistics.stats_count(API_NAME, 'Clone')
+    def clone(self, request, env_template_id, body):
+        """Clones env template from another tenant
+
+        It clones the env template from another env template
+        from other tenant.
+        :param request: the operation request.
+        :param env_template_id: the env template ID.
+        :param body: the request body.
+        :return: the description of the created template.
+        """
+
+        LOG.debug('EnvTemplates:Clone <Env Template {1} for body {0}>'.
+                  format(body, env_template_id))
+        policy.check('clone_env_template', request.context)
+
+        old_env_template = self._validate_exists(env_template_id)
+
+        if not old_env_template.get('is_public'):
+            msg = _('User has no access to these resources.')
+            LOG.error(msg)
+            raise exc.HTTPForbidden(explanation=msg)
+        self._validate_body_name(body)
+        LOG.debug('ENV TEMP NAME: {0}'.format(body['name']))
+
+        try:
+            is_public = body.get('is_public', False)
+            template = env_temps.EnvTemplateServices.clone(
+                env_template_id, request.context.project_id, body['name'],
+                is_public)
+        except db_exc.DBDuplicateEntry:
+            msg = _('Env template with specified name already exists')
+            LOG.error(msg)
+            raise exc.HTTPConflict(explanation=msg)
+
+        return template.to_dict()
+
     def _validate_request(self, request, env_template_id):
+        env_template = self._validate_exists(env_template_id)
+        if env_template.is_public or request.context.is_admin:
+            return
+        if env_template.tenant_id != request.context.project_id:
+            msg = _('User has no access to these resources.')
+            LOG.error(msg)
+            raise exc.HTTPForbidden(explanation=msg)
+
+    def _validate_exists(self, env_template_id):
         env_template_exists = env_temps.EnvTemplateServices.env_template_exist
         if not env_template_exists(env_template_id):
             msg = _('EnvTemplate <TempId {temp_id}> is not found').format(
                 temp_id=env_template_id)
-            LOG.exception(msg)
+            LOG.error(msg)
             raise exc.HTTPNotFound(explanation=msg)
         get_env_template = env_temps.EnvTemplateServices.get_env_template
-        env_template = get_env_template(env_template_id)
-        if env_template.tenant_id != request.context.tenant:
-            LOG.exception(_LE('User is not authorized to access this tenant '
-                              'resources.'))
-            raise exc.HTTPUnauthorized
+        return get_env_template(env_template_id)
+
+    def _validate_body_name(self, body):
+
+        if not('name' in body and body['name'].strip()):
+            msg = _('Please, specify a name of the environment template.')
+            LOG.error(msg)
+            raise exc.HTTPBadRequest(explanation=msg)
+
+        name = str(body['name'])
+        if len(name) > 255:
+            msg = _('Environment template name should be 255 characters '
+                    'maximum')
+            LOG.error(msg)
+            raise exc.HTTPBadRequest(explanation=msg)
 
 
 def create_resource():
