@@ -20,8 +20,6 @@ import uuid
 import eventlet.debug
 from oslo_config import cfg
 from oslo_log import log as logging
-import oslo_messaging as messaging
-from oslo_messaging.rpc import dispatcher
 from oslo_messaging import target
 from oslo_serialization import jsonutils
 from oslo_service import service
@@ -58,18 +56,16 @@ class EngineService(service.Service):
         self.server = None
 
     def start(self):
+        if not rpc.initialized():
+            rpc.init()
         endpoints = [
             TaskProcessingEndpoint(),
             StaticActionEndpoint(),
             SchemaEndpoint()
         ]
 
-        transport = messaging.get_rpc_transport(CONF)
         s_target = target.Target('murano', 'tasks', server=str(uuid.uuid4()))
-        access_policy = dispatcher.DefaultRPCAccessPolicy
-        self.server = messaging.get_rpc_server(
-            transport, s_target, endpoints, 'eventlet',
-            access_policy=access_policy)
+        self.server = rpc.get_server(s_target, endpoints, executor='eventlet')
         self.server.start()
         super(EngineService, self).start()
 
