@@ -16,6 +16,7 @@
 
 from oslo_config import cfg
 from oslo_log import log as logging
+from oslo_policy import opts
 from oslo_policy import policy
 from webob import exc as exceptions
 
@@ -27,6 +28,12 @@ CONF = cfg.CONF
 
 _ENFORCER = None
 
+# TODO(gmann): Remove setting the default value of config policy_file
+# once oslo_policy change the default value to 'policy.yaml'.
+# https://github.com/openstack/oslo.policy/blob/a626ad12fe5a3abd49d70e3e5b95589d279ab578/oslo_policy/opts.py#L49
+DEFAULT_POLICY_FILE = 'policy.yaml'
+opts.set_defaults(CONF, DEFAULT_POLICY_FILE)
+
 
 def reset():
     global _ENFORCER
@@ -96,16 +103,12 @@ def check(rule, ctxt, target=None, do_raise=True, exc=None):
     else:
         return result
     finally:
-        extra = {'policy': {'rule': rule, 'target': target}}
-
         if result:
             LOG.debug("Policy check succeeded for rule {rule} on target "
-                      "{target}".format(rule=rule, target=repr(target),
-                                        extra=extra))
+                      "{target}".format(rule=rule, target=repr(target)))
         else:
             LOG.debug("Policy check failed for rule {rule} on target: "
-                      "{target}".format(rule=rule, target=repr(target),
-                                        extra=extra))
+                      "{target}".format(rule=rule, target=repr(target)))
 
 
 def check_is_admin(context):
