@@ -18,7 +18,7 @@ import io
 import os
 import zipfile
 
-import six
+from murano.common.helpers import path
 
 
 class PackageType(object):
@@ -27,8 +27,7 @@ class PackageType(object):
     ALL = [Library, Application]
 
 
-@six.add_metaclass(abc.ABCMeta)
-class Package(object):
+class Package(object, metaclass=abc.ABCMeta):
     def __init__(self, format_name, runtime_version, source_directory):
         self._source_directory = source_directory
         self._format_name = format_name
@@ -39,15 +38,18 @@ class Package(object):
     def format_name(self):
         return self._format_name
 
-    @abc.abstractproperty
+    @property
+    @abc.abstractmethod
     def full_name(self):
         raise NotImplementedError()
 
-    @abc.abstractproperty
+    @property
+    @abc.abstractmethod
     def version(self):
         raise NotImplementedError()
 
-    @abc.abstractproperty
+    @property
+    @abc.abstractmethod
     def classes(self):
         raise NotImplementedError()
 
@@ -55,39 +57,48 @@ class Package(object):
     def runtime_version(self):
         return self._runtime_version
 
-    @abc.abstractproperty
+    @property
+    @abc.abstractmethod
     def requirements(self):
         raise NotImplementedError()
 
-    @abc.abstractproperty
+    @property
+    @abc.abstractmethod
     def package_type(self):
         raise NotImplementedError()
 
-    @abc.abstractproperty
+    @property
+    @abc.abstractmethod
     def display_name(self):
         raise NotImplementedError()
 
-    @abc.abstractproperty
+    @property
+    @abc.abstractmethod
     def description(self):
         raise NotImplementedError()
 
-    @abc.abstractproperty
+    @property
+    @abc.abstractmethod
     def author(self):
         raise NotImplementedError()
 
-    @abc.abstractproperty
+    @property
+    @abc.abstractmethod
     def supplier(self):
         raise NotImplementedError()
 
-    @abc.abstractproperty
+    @property
+    @abc.abstractmethod
     def tags(self):
         raise NotImplementedError()
 
-    @abc.abstractproperty
+    @property
+    @abc.abstractmethod
     def logo(self):
         raise NotImplementedError()
 
-    @abc.abstractproperty
+    @property
+    @abc.abstractmethod
     def supplier_logo(self):
         raise NotImplementedError()
 
@@ -105,20 +116,22 @@ class Package(object):
     def get_resource(self, name):
         raise NotImplementedError()
 
-    @abc.abstractproperty
+    @property
+    @abc.abstractmethod
     def ui(self):
         raise NotImplementedError()
 
-    @abc.abstractproperty
+    @property
+    @abc.abstractmethod
     def meta(self):
         raise NotImplementedError()
 
 
-def _zip_dir(path, zip_file):
-    for root, _, files in os.walk(path):
+def _zip_dir(base, zip_file):
+    for root, _, files in os.walk(base):
         for f in files:
-            abs_path = os.path.join(root, f)
-            relative_path = os.path.relpath(abs_path, path)
+            abs_path = path.secure_join(root, f)
+            relative_path = os.path.relpath(abs_path, base)
             zip_file.write(abs_path, relative_path)
 
 
