@@ -13,6 +13,7 @@
 
 import copy
 import semantic_version
+import types
 from unittest import mock
 import weakref
 
@@ -232,6 +233,18 @@ class TestDSLHelpers(base.MuranoTestCase):
                               test_parsed, None)
         self.assertEqual('Invalid Serialization Type', str(e))
 
+    def test_function(self):
+        def f():
+            return
+        self.assertTrue(isinstance(helpers.function(f), types.FunctionType))
+
+    def test_function_from_method(self):
+        class C:
+            def m(self):
+                return
+        c = C()
+        self.assertTrue(isinstance(helpers.function(c.m), types.FunctionType))
+
     def test_weak_proxy(self):
         self.assertIsNone(helpers.weak_proxy(None))
 
@@ -252,7 +265,7 @@ class TestDSLHelpers(base.MuranoTestCase):
         result = murano_object_weak_ref.__call__()
 
         self.assertEqual(mock.sentinel.res, result)
-        self.assertEqual('weakref',
+        self.assertEqual(weakref.ReferenceType.__name__,
                          murano_object_weak_ref.ref.__class__.__name__)
 
     def test_weak_ref_with_null_obj(self):
